VkIdAuthData class
Data received in case of successful authorization using VK ID SDK.
- Annotations
Constructors
-
VkIdAuthData.fromMap(Map<
Object?, Object?> map) -
Converts Map<Object?, Object?> to VkIdAuthData.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
Access token.
final
- userData → VkIdUserData
-
User data. First name, last name, email, phone.
final
- userId → int
-
User ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited