VkIdUserData class
User data.
- Annotations
Constructors
-
VkIdUserData.fromMap(Map<
Object?, Object?> map) -
Convert Map<Object?, Object?> to VkIdUserData.
factory
Properties
- email → String?
-
Users email.
final
- firstName → String
-
Name of user.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String
-
Last name of user.
final
- phone → String?
-
Users phone.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited